<?php
/**
 * Options page.
 *
 * @package Flat101\Security\Model\Entity
 */

namespace Flat101\Security\Model\Entity;

use const Flat101\Security\PREFIX;

/**
 * Page class.
 */
class Page {

	/**
	 * Text for the menu of this administration page.
	 *
	 * @var string
	 */
	protected $menu_text = null;

	/**
	 * Page title. It will be displayed at the top of the page.
	 *
	 * @var string
	 */
	protected $page_title = null;

	/**
	 * Option key and admin menu page slug. Must be unique.
	 *
	 * @var string
	 */
	protected $key = null;

	/**
	 * All blocks on this page. They will be displayed respecting their order in the array.
	 *
	 * @var Block[]
	 */
	protected $blocks = array();


	/**
	 * Page constructor.
	 *
	 * @param string  $menu_text Menu text.
	 * @param string  $page_title Page title.
	 * @param string  $key The plugin prefix and suffix "_page" will be added.
	 * @param Block[] $blocks Page blocks.
	 */
	public function __construct( $menu_text, $page_title, $key, $blocks = array() ) {
		$this->menu_text  = $menu_text;
		$this->page_title = $page_title;
		$this->key        = PREFIX . '_' . $key . '_page';
		$this->blocks     = $blocks;
	}


	/**
	 * Text for the menu of this administration page.
	 *
	 * @return string
	 */
	public function get_menu_text() {
		return $this->menu_text;
	}

	/**
	 * Page title.
	 *
	 * @return string
	 */
	public function get_page_title() {
		return $this->page_title;
	}

	/**
	 * Option key and admin menu page slug.
	 *
	 * @return string
	 */
	public function get_key() {
		return $this->key;
	}

	/**
	 * All blocks on this page.
	 *
	 * @return Block[]
	 */
	public function get_blocks() {
		return $this->blocks;
	}

	/**
	 * Remove all blocks from this page.
	 */
	public function empty_blocks() {
		$this->blocks = array();
	}
}
